@@ -67,16 +67,16 @@ class Application(object):
         return self.__resource and self.__resource.name or self.__menu_entry.get_name()
     
     def get_description(self):
-        return self.__resource and self.__resource.description or ""
+        return getattr(self.__resource, "description", "")
 
     def get_tooltip(self):
-        return self.__resource and self.__resource.tooltip or ""
+        return getattr(self.__resource, "tooltip", "")
     
     def get_generic_name(self):
-        return self.__resource and self.__resource.genericName or ""
+        return getattr(self.__resource, "genericName", "")
 
     def get_usage_count(self):
-        return self.__resource and int(self.__resource.usageCount) or 0
+        return getattr(self.__resource, "usageCount", 0)
 
     def get_category(self):
         ## FIXME should this be category or categoryDisplayName ?       
@@ -228,10 +228,10 @@ class AppsHttpDownloader:
         self.__handler(apps)
 
     def __on_error(self, url, args):
-        if 'status' in args and args['status'] == '504':
+        if response and 'status' in response and response['status'] == '504':
             _logger.debug("don't have local cache for %s", url)
         else:
-            _logger.error("failed to get http request %s: %s", self.__relative_url, args)
+            _logger.error("failed to get http request %s: %s", self.__relative_url, response)
         self.__handler([])
         
     def __do_download(self):
